pub struct Verifier {
tx: Sender<Option<Result<(), VerificationError>>>,
}Expand description
Groth16 signature verifier implementation
This is the core implementation for the batch verification logic of the groth verifier. It handles batching incoming requests, driving batches to completion, and reporting results.
Fields
tx: Sender<Option<Result<(), VerificationError>>>A channel for broadcasting the result of a batch to the futures for each batch item.
Each batch gets a newly created channel, so there is only ever one result sent per channel. Tokio doesn’t have a oneshot multi-consumer channel, so we use a watch channel.
Implementations
Sourceimpl Verifier
impl Verifier
Sourceasync fn verify_single_spawning(
item: Item,
pvk: &'static ItemVerifyingKey,
) -> Result<(), BoxError>
async fn verify_single_spawning( item: Item, pvk: &'static ItemVerifyingKey, ) -> Result<(), BoxError>
Verify a single item using a thread pool, and return the result.